@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-   @project: HSPyLib-Vault
+   @project: HsPyLib-Vault
    @package: vault
       @file: __classpath__.py
    @created: Wed, 8 Jun 2022
@@ -10,7 +10,7 @@
       @site: "https://github.com/yorevs/hspylib")
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2022, HSPyLib team
+   Copyright·(c)·2024,·HSPyLib
 """
 
 from hspylib.core.metaclass.classpath import Classpath
@@ -18,11 +18,11 @@ from hspylib.core.tools.commons import get_path, run_dir
 
 
 class _Classpath(Classpath):
-    """TODO"""
+    """Provide a class to help locating user-defined classes, packages, sources and resources."""
 
     def __init__(self):
         super().__init__(get_path(__file__), get_path(run_dir()), (get_path(__file__) / "resources"))
 
 
 # Instantiate the classpath singleton
-_Classpath()
+assert (classpath := _Classpath().INSTANCE) is not None, "Failed to create Classpath instance"
