@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-   @project: HSPyLib-Vault
+   @project: HsPyLib-Vault
    @package: vault
       @file: __main__.py
    @created: Tue, 4 May 2021
@@ -10,7 +10,7 @@
       @site: https://github.com/yorevs/hspylib
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2022, HSPyLib team
+   Copyright·(c)·2024,·HSPyLib
 """
 
 from clitt.core.tui.tui_application import TUIApplication
@@ -20,7 +20,7 @@ from hspylib.core.zoned_datetime import now
 from hspylib.modules.application.exit_status import ExitStatus
 from hspylib.modules.application.version import Version
 from textwrap import dedent
-from vault.__classpath__ import _Classpath
+from vault.__classpath__ import classpath
 from vault.core.vault import Vault
 from vault.core.vault_config import VaultConfig
 from vault.exception.exceptions import VaultOpenError
@@ -31,20 +31,19 @@ import sys
 
 
 class Main(TUIApplication):
-    """HSPyLib Vault - Manage your secrets"""
+    """HsPyLib Vault - Manage your secrets"""
 
     # The welcome message
-    DESCRIPTION = _Classpath.get_source_path("welcome.txt").read_text(encoding=Charset.UTF_8.val)
+    DESCRIPTION = classpath.get_source("welcome.txt").read_text(encoding=Charset.UTF_8.val)
 
     # location of the .version file
-    VERSION_DIR = _Classpath.source_path()
+    VERSION = Version.load(load_dir=classpath.source_path())
 
     # The resources folder
-    RESOURCE_DIR = str(_Classpath.resource_path())
+    RESOURCE_DIR = str(classpath.resource_path())
 
     def __init__(self, app_name: str):
-        version = Version.load(load_dir=self.VERSION_DIR)
-        super().__init__(app_name, version, self.DESCRIPTION.format(version), resource_dir=self.RESOURCE_DIR)
+        super().__init__(app_name, self.VERSION, self.DESCRIPTION.format(self.VERSION), resource_dir=self.RESOURCE_DIR)
         self.vault = Vault(self.RESOURCE_DIR)
 
     def _setup_arguments(self) -> None:
