@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-   @project: HSPyLib-Vault
+   @project: HsPyLib-Vault
    @package: vault.core
       @file: vault.py
    @created: Tue, 4 May 2021
@@ -10,19 +10,22 @@
       @site: https://github.com/yorevs/hspylib
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2022, HSPyLib team
+   Copyright·(c)·2024,·HSPyLib
 """
 
 from cryptography.fernet import InvalidToken
 from datasource.identity import Identity
 from hspylib.core.preconditions import check_not_none
 from hspylib.core.tools.commons import file_is_not_empty, safe_delete_file, syserr, sysout, touch_file
+from hspylib.core.tools.text_tools import ensure_startswith, ensure_endswith
+from hspylib.modules.application.application import Application
+from hspylib.modules.application.exit_status import ExitStatus
 from hspylib.modules.cache.ttl_keyring_be import TTLKeyringBE
 from hspylib.modules.security.security import b64_decode, decode_file, decrypt_file, encode_file, encrypt_file
 from typing import List
 from vault.core.vault_config import VaultConfig
 from vault.core.vault_service import VaultService
-from vault.entity.vault_entry import VaultEntry
+from vault.domain.vault_entry import VaultEntry
 from vault.exception.exceptions import VaultCloseError, VaultExecutionException, VaultSecurityException
 
 import binascii
@@ -37,7 +40,7 @@ import uuid
 
 
 class Vault:
-    """Represents the vault and it's functionalities"""
+    """Represents the vault and it's functionalities."""
 
     # Vault hash code
     _VAULT_HASHCODE = os.getenv("VAULT_HASHCODE", "e4f362fd1e02df6bc9c684c9310e3550")
@@ -45,6 +48,9 @@ class Vault:
     # Vault keyring cache entry
     _VAULT_CACHE_NAME = "VAULT_KEY_SERVICE"
 
+    # Maximum authentication retries
+    MAX_AUTH_RETRIES = 3
+
     def __init__(self, resource_dir: str) -> None:
         self._is_unlocked = False
         self._passphrase = None
@@ -65,26 +71,31 @@ class Vault:
 
     @contextlib.contextmanager
     def open(self) -> bool:
-        """Open and read the Vault file"""
-        try:
-            self._sanity_check()
+        """Open and read the Vault file."""
+        retries = 0
+        self._sanity_check()
+        while not self._is_unlocked and not self._passphrase and retries < self.MAX_AUTH_RETRIES:
             self._passphrase = self._read_passphrase()
-            if not self._is_unlocked:
-                self._unlock_vault()
-                log.debug("Vault open and unlocked")
-            yield self._is_unlocked or None
-        except (UnicodeDecodeError, InvalidToken, binascii.Error) as err:
-            log.error("Authentication failure => %s", err)
-            syserr("Authentication failure")
-            keyring.delete_password(self._VAULT_CACHE_NAME, self._configs.vault_user)
-            yield None
-        finally:
+            try:
+                if not self._is_unlocked:
+                    self._unlock_vault()
+                    log.debug("Vault open and unlocked")
+                yield self._is_unlocked
+            except (UnicodeDecodeError, InvalidToken, binascii.Error) as err:
+                log.error("Authentication failure => %s", err)
+                syserr("Authentication failure!")
+                keyring.delete_password(self._VAULT_CACHE_NAME, self._configs.vault_user)
+                self._passphrase = None
+                retries += 1
+        if self._is_unlocked:
             self.close()
+        else:
+            Application.exit(ExitStatus.FAILED.val)
 
         return self._is_unlocked
 
     def close(self) -> bool:
-        """Close the Vault file and cleanup temporary file_paths"""
+        """Close the Vault file and cleanup temporary files."""
         try:
             if self._is_unlocked:
                 self._lock_vault()
@@ -100,7 +111,7 @@ class Vault:
 
     def list(self, filter_expr: List[str] = None) -> None:
         """List all vault entries filtered by filter_expr
-        :param filter_expr: The filter expression
+        :param filter_expr: The entry filter expression.
         """
         data = self.service.list_by_key(filter_expr)
         if len(data) > 0:
@@ -121,19 +132,17 @@ class Vault:
 
     def add(self, key: str, hint: str | None, password: str | None) -> None:
         """Add a vault entry
-        :param key: The vault entry name to be added
-        :param hint: The vault entry hint to be added
-        :param password: The vault entry password to be added
+        :param key: the vault entry key to be added.
+        :param hint: the vault entry hint to be added.
+        :param password: the vault entry password to be added.
         """
         check_not_none(key)
         if not self.service.exists(key):
-            entry = VaultEntry(
-                Identity(VaultEntry.VaultId(uuid.uuid4().hex)),
-                key, key, password, hint,
-            )
+            entry = VaultEntry(Identity(VaultEntry.VaultId(uuid.uuid4().hex)), key, key, password, hint)
             if not hint or not password:
                 entry = VaultEntry.prompt(entry)
             if entry:
+                entry.password = self._encrypt_passphrase(entry.password)
                 self.service.save(entry)
                 sysout(f"%GREEN%%EOL%=== Entry saved ===%EOL%%EOL%%NC%{entry.to_string()}")
         else:
@@ -143,18 +152,18 @@ class Vault:
 
     def update(self, key: str, hint: str | None, password: str | None) -> None:
         """Update a vault entry
-        :param key: The vault entry name to be updated
-        :param hint: The vault entry hint to be updated
-        :param password: The vault entry password to be updated
+        :param key: the vault entry key to be updated.
+        :param hint: the vault entry hint to be updated.
+        :param password: the vault entry password to be updated.
         """
         check_not_none(key)
         if entry := self.service.get_by_key(key):
             entry.hint = hint if hint else entry.hint
-            entry.password = password if password else self._decrypt_password(entry.password)
+            entry.password = password if password else self._decrypt_passphrase(entry.password)
             if not hint or not password:
                 entry = VaultEntry.prompt(entry)
             if entry:
-                entry.password = self._encrypt_password(entry.password)
+                entry.password = self._encrypt_passphrase(entry.password)
                 self.service.save(entry)
                 sysout(f"%GREEN%%EOL%=== Entry updated ===%EOL%%EOL%%NC%{entry.to_string()}")
         else:
@@ -164,7 +173,7 @@ class Vault:
 
     def get(self, key) -> None:
         """Display the vault entry specified by name
-        :param key: The vault entry name to get
+        :param key: the vault entry key to get
         """
         entry = self.service.get_by_key(key)
         if entry:
@@ -177,7 +186,7 @@ class Vault:
 
     def remove(self, key: str) -> None:
         """Remove a vault entry
-        :param key: The vault entry name to be removed
+        :param key: The vault entry key to be removed
         """
         entry = self.service.get_by_key(key)
         if entry:
@@ -188,14 +197,20 @@ class Vault:
             syserr(f"### No entry specified by '{key}' was found in vault")
         log.debug("Vault remove issued. User=%s", getpass.getuser())
 
-    def _encrypt_password(self, password: str) -> str:
-        return cryptocode.encrypt(password, self._VAULT_HASHCODE)
+    def _encrypt_passphrase(self, passphrase: str) -> str:
+        """Encrypt current assigned passphrase.
+        :param passphrase: the passphrase to encrypt.
+        """
+        return cryptocode.encrypt(passphrase, self._VAULT_HASHCODE)
 
-    def _decrypt_password(self, password: str) -> str:
-        return cryptocode.decrypt(password, self._VAULT_HASHCODE)
+    def _decrypt_passphrase(self, passphrase: str) -> str:
+        """Decrypt current assigned passphrase.
+        :param passphrase: the passphrase to decrypt.
+        """
+        return cryptocode.decrypt(passphrase, self._VAULT_HASHCODE)
 
     def _read_passphrase(self) -> str:
-        """Retrieve and read the vault passphrase"""
+        """Read and return the vault currently assigned passphrase."""
         passphrase, confirm_passphrase = None, False
         if file_is_not_empty(self._configs.vault_file):
             if self._configs.passphrase:
@@ -203,7 +218,7 @@ class Vault:
         else:
             sysout(f"%ORANGE%### Your Vault '{self._configs.vault_file}' file does not exist ###")
             sysout("%ORANGE%>>> Enter the new passphrase to create a new Vault file <<<")
-            if not (confirm_passphrase := self._create_vault_file()):
+            if not (confirm_passphrase := self._create_new_vault()):
                 raise VaultExecutionException(f"Unable to create vault file: {self._configs.vault_file}")
         while not passphrase:
             passphrase = self._getpass(confirm_passphrase)
@@ -225,7 +240,7 @@ class Vault:
         return f"{self._configs.vault_user}:{passphrase}"
 
     def _lock_vault(self) -> None:
-        """Encode and Encrypt the vault file"""
+        """Lock the vault file (encode & encrypt)."""
         if file_is_not_empty(self._configs.unlocked_vault_file):
             encoded = f"{self._configs.unlocked_vault_file}-encoded"
             encode_file(self._configs.unlocked_vault_file, encoded, binary=True)
@@ -238,7 +253,7 @@ class Vault:
         safe_delete_file(self._configs.unlocked_vault_file)
 
     def _unlock_vault(self) -> None:
-        """Decrypt and Decode the vault file"""
+        """Unlock the vault file (decode & decrypt)."""
         if file_is_not_empty(self._configs.vault_file):
             encoded = f"{self._configs.unlocked_vault_file}-encoded"
             decrypt_file(self._configs.vault_file, encoded, self._passphrase)
@@ -254,7 +269,8 @@ class Vault:
         """Check existing vault backups and apply a rollback if required."""
         vault_file = self._configs.vault_file
         unlocked_vault_file = self._configs.unlocked_vault_file
-        backup_file = f"{os.getenv('HOME', os.getenv('TEMP', '/tmp'))}/.{os.path.basename(vault_file)}.bak"
+        backup_file = ensure_endswith(ensure_startswith(f"{os.path.basename(vault_file)}", '.'), '.bak')
+        backup_file = f"{os.getenv('HHS_BACKUP_DIR', os.getenv('HOME', os.getenv('TEMP', '/tmp')))}/{backup_file}"
         locked_empty = not file_is_not_empty(vault_file)
         unlocked_empty = not file_is_not_empty(unlocked_vault_file)
         if not locked_empty or not unlocked_empty:
@@ -268,20 +284,22 @@ class Vault:
                     shutil.copyfile(backup_file, vault_file)
                     safe_delete_file(unlocked_vault_file)
                 else:
-                    log.warning("No backups found !")
+                    log.error("No backups found !")
                     raise VaultSecurityException(
                         "Unable to either restore or re-lock the vault file. Please manually "
                         + f' backup your secrets and remove the unlocked file "{unlocked_vault_file}"'
                     )
 
     def _getpass(self, skip_cache: bool) -> str:
-        """Prompt for the user password or retrieved the cached one."""
+        """Prompt for the user password or retrieved the cached one if skip cache is not set.
+        :param skip_cache: whether to skip the cached password value or not.
+        """
         if skip_cache or (passwd := keyring.get_password(self._VAULT_CACHE_NAME, self._configs.vault_user)) is None:
             passwd = getpass.getpass("Enter passphrase:").rstrip()
             keyring.set_password(self._VAULT_CACHE_NAME, self._configs.vault_user, passwd)
         return passwd
 
-    def _create_vault_file(self) -> bool:
+    def _create_new_vault(self) -> bool:
         """Create the vault SQLite DB file."""
         touch_file(self._configs.vault_file)
         self.service.create_vault_db()
