@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-   @project: HSPyLib-Vault
+   @project: HsPyLib-Vault
    @package: vault.core
       @file: vault_config.py
    @created: Tue, 4 May 2021
@@ -10,13 +10,13 @@
       @site: https://github.com/yorevs/hspylib
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2022, HSPyLib team
+   Copyright·(c)·2024,·HSPyLib
 """
 from datasource.db_configuration import DBConfiguration
 
 
 class VaultConfig(DBConfiguration):
-    """Holds the vault configurations"""
+    """Holds the vault configurations."""
 
     INSTANCE = None
 
