@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-   @project: HSPyLib-Vault
+   @project: HsPyLib-Vault
    @package: vault.core
       @file: vault_repository.py
    @created: Tue, 4 May 2021
@@ -10,15 +10,18 @@
       @site: https://github.com/yorevs/hspylib
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2022, HSPyLib team
+   Copyright·(c)·2024,·HSPyLib
 """
 from datasource.identity import Identity
 from datasource.sqlite.sqlite_repository import SQLiteRepository
 from typing import Optional, Set
-from vault.entity.vault_entry import VaultEntry
+from vault.core.vault_config import VaultConfig
+from vault.domain.vault_entry import VaultEntry
 
 
-class VaultRepository(SQLiteRepository[VaultEntry]):
+class VaultRepository(SQLiteRepository[VaultEntry, VaultConfig]):
+    """Provide CRUD operations for the Vault application."""
+
     @property
     def database(self) -> str:
         return self._config.database
@@ -44,5 +47,9 @@ class VaultRepository(SQLiteRepository[VaultEntry]):
             return VaultEntry(Identity(VaultEntry.VaultId(entity_dict["uuid"])), **entity_dict)
         return VaultEntry(
             Identity(VaultEntry.VaultId(entity_dict[0])),
-            entity_dict[1], entity_dict[2], entity_dict[3], entity_dict[4], entity_dict[5]
+            entity_dict[1],
+            entity_dict[2],
+            entity_dict[3],
+            entity_dict[4],
+            entity_dict[5],
         )
