@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 """
-   @project: HSPyLib-Vault
+   @project: HsPyLib-Vault
    @package: vault.exception
       @file: exceptions.py
    @created: Tue, 4 May 2021
@@ -10,7 +10,7 @@
       @site: https://github.com/yorevs/hspylib
    @license: MIT - Please refer to <https://opensource.org/licenses/MIT>
 
-   Copyright 2022, HSPyLib team
+   Copyright·(c)·2024,·HSPyLib
 """
 from hspylib.core.exception.exceptions import HSBaseException
 
@@ -23,6 +23,10 @@ class VaultOpenError(HSBaseException):
     """Raised when opening the vault"""
 
 
+class VaultAuthenticationError(HSBaseException):
+    """Raised when vault authentication has failed"""
+
+
 class VaultSecurityException(HSBaseException):
     """Raised when something unexpected happened to vault file"""
 
